summaryrefslogtreecommitdiff
path: root/examples/api/cpp/extract.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/api/cpp/extract.cpp')
-rw-r--r--examples/api/cpp/extract.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/api/cpp/extract.cpp b/examples/api/cpp/extract.cpp
index d21c59d59..b5de58d26 100644
--- a/examples/api/cpp/extract.cpp
+++ b/examples/api/cpp/extract.cpp
@@ -10,7 +10,7 @@
* directory for licensing information.
* ****************************************************************************
*
* A simple demonstration of the solving capabilities of the CVC4
* bit-vector solver.
*
*/
@@ -50,7 +50,7 @@ int main()
Term eq2 = slv.mkTerm(EQUAL, x_31_31, x_0_0);
cout << " Check entailment assuming: " << eq2 << endl;
cout << " Expect ENTAILED. " << endl;
- cout << " CVC4: " << slv.checkEntailed(eq2) << endl;
+ cout << " cvc5: " << slv.checkEntailed(eq2) << endl;
return 0;
}
generated by cgit on debian on lair
@@ -10,7 +10,7 @@
* ****************************************************************************
*
- * A simple demonstration of the solving capabilities of the CVC4
+ * A simple demonstration of the solving capabilities of the cvc5
* bit-vector solver.
*
contact matthew@masot.net with questions or feedback